@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
-from huaweicloud_sis.utils.logger_utils import logger
-from huaweicloud_sis.exception.exceptions import ClientException
+from hwsis.utils.logger_utils import logger
+from hwsis.exception.exceptions import ClientException
 
 
 class RasrCallBack:
