@@ -1,4 +1,4 @@
-from huaweicloud_sis.utils.logger_utils import logger
+from hwsis.utils.logger_utils import logger
 
 
 class HotWordRequest:
