@@ -2,8 +2,8 @@
 
 import base64
 import os
-from huaweicloud_sis.utils.logger_utils import logger
-from huaweicloud_sis.exception.exceptions import ClientException
+from hwsis.utils.logger_utils import logger
+from hwsis.exception.exceptions import ClientException
 
 
 def encode_file(file_path):
