@@ -6,11 +6,11 @@ logging.basicConfig(
     format='[%(asctime)s] - [%(levelname)s] - [%(message)s]'
 )
 # 设置handler
-file_handler = logging.handlers.RotatingFileHandler('huaweicloud_sis.log', maxBytes=1024*1024,
+file_handler = logging.handlers.RotatingFileHandler('hwsis.log', maxBytes=1024*1024,
                                                     backupCount=5, encoding='utf-8')
 file_handler.setLevel(logging.INFO)
 file_handler.setFormatter(logging.Formatter('[%(asctime)s] - [%(levelname)s] - [%(message)s]'))
 
 # 添加file_handler
-logger = logging.getLogger('huaweicloud_sis')
+logger = logging.getLogger('hwsis')
 logger.addHandler(file_handler)
